@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,6 +25,10 @@
 namespace KPIM {
 class StatusbarProgressWidget;
 class ProgressStatusBarWidgetPrivate;
+/**
+ * @brief The ProgressStatusBarWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KDEPIM_EXPORT ProgressStatusBarWidget : public QObject
 {
     Q_OBJECT
@@ -32,7 +36,7 @@ public:
     explicit ProgressStatusBarWidget(QWidget *alignWidget, QWidget *parent = nullptr, unsigned int showTypeProgressItem = 0);
     ~ProgressStatusBarWidget();
 
-    KPIM::StatusbarProgressWidget *littleProgress() const;
+    Q_REQUIRED_RESULT KPIM::StatusbarProgressWidget *littleProgress() const;
 
 private:
     ProgressStatusBarWidgetPrivate *const d;
