@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -18,9 +18,10 @@
 */
 
 #include "progressindicatorlabel.h"
-#include "progressindicatorwidget.h"
+#include <KBusyIndicatorWidget>
 
 #include <QHBoxLayout>
+#include <QLabel>
 
 using namespace KPIM;
 class KPIM::ProgressIndicatorLabelPrivate
@@ -31,8 +32,8 @@ public:
         , q(qq)
     {
         QHBoxLayout *lay = new QHBoxLayout(q);
-        lay->setMargin(0);
-        indicator = new ProgressIndicatorWidget;
+        lay->setContentsMargins(0, 0, 0, 0);
+        indicator = new KBusyIndicatorWidget;
         lay->addWidget(indicator);
         label = new QLabel;
         lay->addWidget(label);
@@ -44,26 +45,26 @@ public:
 
     void setActiveLabel(const QString &str)
     {
-        if (indicator->isActive()) {
+        if (!indicator->isHidden()) {
             label->setText(str);
         }
     }
 
     void start()
     {
-        indicator->start();
+        indicator->show();
         label->setText(labelStr);
     }
 
     void stop()
     {
-        indicator->stop();
+        indicator->hide();
         label->clear();
     }
 
     QString labelStr;
     QLabel *label = nullptr;
-    ProgressIndicatorWidget *indicator = nullptr;
+    KBusyIndicatorWidget *indicator = nullptr;
     ProgressIndicatorLabel *q;
 };
 
@@ -71,12 +72,14 @@ ProgressIndicatorLabel::ProgressIndicatorLabel(const QString &label, QWidget *pa
     : QWidget(parent)
     , d(new ProgressIndicatorLabelPrivate(label, this))
 {
+    d->stop();
 }
 
 ProgressIndicatorLabel::ProgressIndicatorLabel(QWidget *parent)
     : QWidget(parent)
     , d(new ProgressIndicatorLabelPrivate(QString(), this))
 {
+    d->stop();
 }
 
 ProgressIndicatorLabel::~ProgressIndicatorLabel()
